/*
 *    Copyright (c) 2018-2025, lengleng All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 * Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 * Neither the name of the yifu4cloud.com developer nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 * Author: lengleng (wangiegie@gmail.com)
 */

package com.yifu.cloud.plus.v1.consumer.controller;

import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.yifu.cloud.plus.v1.yifu.common.core.util.R;
import com.yifu.cloud.plus.v1.yifu.common.log.annotation.SysLog;
import com.yifu.cloud.plus.v1.consumer.entity.Consumer;
import com.yifu.cloud.plus.v1.consumer.service.ConsumerService;
import org.springframework.security.access.prepost.PreAuthorize;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.security.SecurityRequirement;
import io.swagger.v3.oas.annotations.tags.Tag;
import lombok.RequiredArgsConstructor;
import org.springframework.http.HttpHeaders;
import org.springframework.web.bind.annotation.*;


/**
 * consumer表
 *
 * @author fxj
 * @date 2022-05-13 23:28:12
 */
@RestController
@RequiredArgsConstructor
@RequestMapping("/consumer" )
@Tag(name = "consumer表管理")
@SecurityRequirement(name = HttpHeaders.AUTHORIZATION)
public class ConsumerController {

    private final  ConsumerService consumerService;

    /**
     * 分页查询
     * @param page 分页对象
     * @param consumer consumer表
     * @return
     */
    @Operation(summary = "分页查询", description = "分页查询")
    @GetMapping("/page" )
    @PreAuthorize("@pms.hasPermission('consumer_consumer_get')" )
    public R getConsumerPage(Page page, Consumer consumer) {
        return R.ok(consumerService.page(page, Wrappers.query(consumer)));
    }


    /**
     * 通过id查询consumer表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id查询", description = "通过id查询")
    @GetMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('consumer_consumer_get')" )
    public R getById(@PathVariable("id" ) Long id) {
        return R.ok(consumerService.getById(id));
    }

    /**
     * 新增consumer表
     * @param consumer consumer表
     * @return R
     */
    @Operation(summary = "新增consumer表", description = "新增consumer表")
    @SysLog("新增consumer表" )
    @PostMapping
    @PreAuthorize("@pms.hasPermission('consumer_consumer_add')" )
    public R save(@RequestBody Consumer consumer) {
        return R.ok(consumerService.saveTestSeata(consumer));
    }

    /**
     * 修改consumer表
     * @param consumer consumer表
     * @return R
     */
    @Operation(summary = "修改consumer表", description = "修改consumer表")
    @SysLog("修改consumer表" )
    @PutMapping
    @PreAuthorize("@pms.hasPermission('consumer_consumer_edit')" )
    public R updateById(@RequestBody Consumer consumer) {
        return R.ok(consumerService.updateById(consumer));
    }

    /**
     * 通过id删除consumer表
     * @param id id
     * @return R
     */
    @Operation(summary = "通过id删除consumer表", description = "通过id删除consumer表")
    @SysLog("通过id删除consumer表" )
    @DeleteMapping("/{id}" )
    @PreAuthorize("@pms.hasPermission('consumer_consumer_del')" )
    public R removeById(@PathVariable Long id) {
        return R.ok(consumerService.removeById(id));
    }

}
